<!DOCTYPE TS><TS>
<defaultcodec>iso8859-1</defaultcodec>
<context>
    <name>EditorToolBar</name>
    <message>
        <source>Cut (Ctrl + X)</source>
        <translation>Knippen (Ctrl + X)</translation>
    </message>
    <message>
        <source>Copy (Ctrl + C)</source>
        <translation>Kopieren (Ctrl + C)</translation>
    </message>
    <message>
        <source>Paste (Ctrl + V)</source>
        <translation>Plakken (Ctrl + V)</translation>
    </message>
    <message>
        <source>Undo (Ctrl + Z)</source>
        <translation>Ongedaan maken (Ctrl + Z)</translation>
    </message>
    <message>
        <source>Redo (Ctrl + R)</source>
        <translation>Opnieuw (Ctrl + R)</translation>
    </message>
    <message>
        <source>Power (Ctrl + 6)</source>
        <translation>Macht (Ctrl + 6)</translation>
    </message>
    <message>
        <source>Parentheses (()</source>
        <translation>Haakjes (()</translation>
    </message>
    <message>
        <source>Absolute value (|)</source>
        <translation>Absolute waarde (|)</translation>
    </message>
    <message>
        <source>Fraction (Ctrl + /)</source>
        <translation>Breuk (Ctrl + /)</translation>
    </message>
    <message>
        <source>Root (Ctrl + 2)</source>
        <translation>Wortel (Ctrl + 2)</translation>
    </message>
</context>
<context>
    <name>G_measureObject</name>
    <message>
        <source>Distance {%1} {%2}</source>
        <translation>Afstand {%1} {%2}</translation>
    </message>
    <message>
        <source>Circumference {%1}</source>
        <translation>Omtrek {%1}</translation>
    </message>
    <message>
        <source>Length {%1}</source>
        <translation>Lengte {%1}</translation>
    </message>
    <message>
        <source>Radius {%1}</source>
        <translation>Straal {%1}</translation>
    </message>
    <message>
        <source>Arc Angle {%1}</source>
        <translation>Boog hoek {%1}</translation>
    </message>
    <message>
        <source>Angle {%1}{%2}{%3}</source>
        <translation>Hoek {%1}{%2}{%3}</translation>
    </message>
    <message>
        <source>Ratio {%1}/{%2}</source>
        <translation>Verhouding {%1}/{%2}</translation>
    </message>
    <message>
        <source>Slope {%1}</source>
        <translation>Hellingshoek {%1}</translation>
    </message>
    <message>
        <source>Area {%1}</source>
        <translation>Oppervlak {%1}</translation>
    </message>
</context>
<context>
    <name>G_ref</name>
    <message>
        <source>Point</source>
        <translation>Punt</translation>
    </message>
    <message>
        <source>Segment</source>
        <translation>Lijnstuk</translation>
    </message>
    <message>
        <source>Ray</source>
        <translation>Halve lijn</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lijn</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>Cirkel</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>Boog</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>Polygoon</translation>
    </message>
    <message>
        <source>Circle Interior</source>
        <translation>Cirkelbinnenkant</translation>
    </message>
    <message>
        <source>Arc Sector</source>
        <translation>Booggebied</translation>
    </message>
    <message>
        <source>Arc Segment</source>
        <translation>Boogstuk</translation>
    </message>
    <message>
        <source>Locus</source>
        <translation>Locus</translation>
    </message>
    <message>
        <source>Measurement</source>
        <translation>Meting</translation>
    </message>
    <message>
        <source>Calculation</source>
        <translation>Berekening</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>Notitie</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
</context>
<context>
    <name>G_valueObject</name>
    <message>
        <source>undefined</source>
        <translation>ongedefinieerd</translation>
    </message>
</context>
<context>
    <name>KSegCalculateEditor</name>
    <message>
        <source>Value is undefined</source>
        <translation>Waarde is ongedefinieerd</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Value is %1</source>
        <translation>Waarde is %1</translation>
    </message>
    <message>
        <source>Insert %1 %2</source>
        <comment>For example, &quot;Insert Measurement M1&quot;</comment>
        <translation>Voer %1 %2 in</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Klaar</translation>
    </message>
</context>
<context>
    <name>KSegConstructionList</name>
    <message>
        <source>Loop on %1</source>
        <translation>Ga door op %1</translation>
    </message>
    <message>
        <source>or</source>
        <translation>of</translation>
    </message>
    <message>
        <source>final</source>
        <translation>uiteindelijk</translation>
    </message>
    <message>
        <source>initial</source>
        <translation>oorspronkelijk</translation>
    </message>
    <message>
        <source>not constructed</source>
        <translation>niet geconstrueerd</translation>
    </message>
    <message>
        <source>doesn&apos;t exist</source>
        <translation>bestaat niet</translation>
    </message>
    <message>
        <source>hidden</source>
        <translation>verborgen</translation>
    </message>
    <message>
        <source>Given</source>
        <translation>Gegeven</translation>
    </message>
    <message>
        <source>Final</source>
        <translation>Uiteindelijk</translation>
    </message>
    <message>
        <source>Initial</source>
        <translation>Oorspronkelijk</translation>
    </message>
    <message>
        <source>%1 is the translation of %2 by the vector from %3 to %4</source>
        <translation>%1 is de translatie van %2 volgens de vector van %3 naar %4</translation>
    </message>
    <message>
        <source>%1 is the rotation of %2 about %3 by angle %4</source>
        <translation>%1 is de rotatie van %2 over %3 door hoek %4</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by the ratio %4:%5</source>
        <translation>%1 is het beeld van %2 geschaald op %3 onder de verhouding %4:%5</translation>
    </message>
    <message>
        <source>%1 is the image of %2 scaled about %3 by ratio %4</source>
        <translation>%1 is het beeld van %2 geschaald op %3 door de verhouding %4</translation>
    </message>
    <message>
        <source>%1 is the reflection of %2 about %3</source>
        <translation>%1 is de reflectie van %2 over %3</translation>
    </message>
    <message>
        <source>%1 is free</source>
        <translation>%1 staat vrij</translation>
    </message>
    <message>
        <source>%1 is on %2</source>
        <translation>%1 ligt op %2</translation>
    </message>
    <message>
        <source>%1 is the intersection of %2 and %3</source>
        <translation>%1 is het snijpunt van %2 en %3</translation>
    </message>
    <message>
        <source>%1 is the 2nd intersection of %2 and %3</source>
        <translation>%1 is het tweede snijpunt van %2 en %3</translation>
    </message>
    <message>
        <source>%1 is the midpoint of %2</source>
        <translation>%1 is het middelpunt van %2</translation>
    </message>
    <message>
        <source>%1 has endpoints %2 and %3</source>
        <translation>%1 heeft de eindpunten %2 en %3</translation>
    </message>
    <message>
        <source>%1 is from %2 through %3</source>
        <translation>%1 is van %2 door %3</translation>
    </message>
    <message>
        <source>%1 bisects angle %2 %3 %4</source>
        <translation>%1 snijdt hoek %2 %3 %4 doormidden</translation>
    </message>
    <message>
        <source>%1 is between %2 and %3</source>
        <translation>%1 ligt op %2 en %3</translation>
    </message>
    <message>
        <source>%1 is parallel to %2 through %3</source>
        <translation>%1 ligt parallel t.ov. %2 door %3</translation>
    </message>
    <message>
        <source>%1 is perpendicular to %2 through %3</source>
        <translation>%1 ligt loodrecht op %2 door %3</translation>
    </message>
    <message>
        <source>%1 is centered at %2 and passes through %3</source>
        <translation>%1 is gecentreerd op %2 gaat door %3</translation>
    </message>
    <message>
        <source>%1 has center at %2 and radius %3</source>
        <translation>%1 heeft midden op %2 en verhouding %3</translation>
    </message>
    <message>
        <source>%1 passes through points %2, %3, and %4</source>
        <translation>%1 gaat door %2, %3 en %4</translation>
    </message>
    <message>
        <source>%1 is traced by %2, driven by %3</source>
        <translation>%1 is getraceerd door %2, aangedreven door %3</translation>
    </message>
    <message>
        <source>%1 involves %2</source>
        <translation>%1 beinvoedt %2</translation>
    </message>
    <message>
        <source>%1 is the distance between %2 and %3</source>
        <translation>%1 is de afstand tussen %2 en %3</translation>
    </message>
    <message>
        <source>%1 is the length of %2</source>
        <translation>%1 is de lengte van %2</translation>
    </message>
    <message>
        <source>%1 is the angle of %2</source>
        <translation>%1 is de hoek van %2</translation>
    </message>
    <message>
        <source>%1 is the angle between points %1, %2, and %3</source>
        <translation>%1 is de hoek van de punten %1, %2, en %3</translation>
    </message>
    <message>
        <source>%1 is the ratio of %2 to %3</source>
        <translation>%1 is de verhouding %2 staat tot %3</translation>
    </message>
    <message>
        <source>%1 is the slope of %2</source>
        <translation>%1 is de hellingshoek van %2</translation>
    </message>
    <message>
        <source>%1 is the area of %2</source>
        <translation>%1 is de oppervlakte van %2</translation>
    </message>
    <message>
        <source>%1 is defined by %2</source>
        <translation>%1 is gedefinieerd door %2</translation>
    </message>
    <message>
        <source>%1 has vertices at points %2</source>
        <translation>%1 heeft hoekpunten op punten %2</translation>
    </message>
    <message>
        <source>%1 is the radius of %2</source>
        <translation>%1 is de straal van %2</translation>
    </message>
    <message>
        <source>%1 is the endpoint of %2</source>
        <translation>%1 is het eindpunt van %2</translation>
    </message>
    <message>
        <source>%1 is the 2nd endpoint of %2</source>
        <translation>%1 is het tweede eindpunt van %2</translation>
    </message>
    <message>
        <source>%1 is the center of %2</source>
        <translation>%1 is het midden van %2</translation>
    </message>
</context>
<context>
    <name>KSegDocument</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>KSegPreferencesDialog</name>
    <message>
        <source>KSEG Preferences</source>
        <translation>KSEG Voorkeuren</translation>
    </message>
    <message>
        <source>Background Color</source>
        <translation>Achtergrondkleur</translation>
    </message>
    <message>
        <source>Default Foreground Color</source>
        <translation>Standaard voorgrondkleur</translation>
    </message>
    <message>
        <source>Selection Display</source>
        <translation>Selectie</translation>
    </message>
    <message>
        <source>Border Selection</source>
        <translation>Omkaderend</translation>
    </message>
    <message>
        <source>Blinking Selection</source>
        <translation>Knipperend</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>KSegRecursionDialog</name>
    <message>
        <source>Enter recursion depth:</source>
        <translation>Voer de recursieve diepte in:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Will produce too many objects.</source>
        <translation>Dit zal te veel objecten aanmaken.</translation>
    </message>
    <message>
        <source>Will produce %1 objects.</source>
        <translation>Dit zal %1 objecten aanmaken.</translation>
    </message>
</context>
<context>
    <name>KSegSampleChangeDialog</name>
    <message>
        <source>Samples in locus:</source>
        <translation>Voorbeeld in locus:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
<context>
    <name>KSegSelectionGroupDialog</name>
    <message>
        <source>Select</source>
        <translation>Selecteer</translation>
    </message>
    <message>
        <source>Deselect</source>
        <translation>Deselecteer</translation>
    </message>
    <message>
        <source>New Group</source>
        <translation>Nieuwe groep</translation>
    </message>
    <message>
        <source>Delete Group</source>
        <translation>Verwijder groep</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Affect
Invisible
Items</source>
        <translation>(De)selecteer
onzichtbare
objecten</translation>
    </message>
    <message>
        <source>Hold SHIFT and click to add to current selection</source>
        <translation>Houd SHIFT ingedrukt en klik om aan de huidige selectie toe te voegen</translation>
    </message>
    <message>
        <source>Whether the &quot;All &lt;Type&gt;&quot; groups also (de)select invisible objects</source>
        <translation>Of de groepen van &quot;Alle &lt;type&gt;&quot; ook onzichtbare items moeten (de)selecteren</translation>
    </message>
    <message>
        <source>All Points</source>
        <translation>Alle punten</translation>
    </message>
    <message>
        <source>All Segments</source>
        <translation>Alle lijnstukken</translation>
    </message>
    <message>
        <source>All Rays</source>
        <translation>Alle halve lijnen</translation>
    </message>
    <message>
        <source>All Lines</source>
        <translation>Alle lijnen</translation>
    </message>
    <message>
        <source>All Circles</source>
        <translation>Alle cirkels</translation>
    </message>
    <message>
        <source>All Arcs</source>
        <translation>Alle bogen</translation>
    </message>
    <message>
        <source>All Polygons</source>
        <translation>Alle polygonen</translation>
    </message>
    <message>
        <source>All Circle Interiors</source>
        <translation>Alle oppervlaktes van cirkel</translation>
    </message>
    <message>
        <source>All Arc Sectors</source>
        <translation>Alle booggebieden</translation>
    </message>
    <message>
        <source>All Arc Segments</source>
        <translation>Alle boogstukken</translation>
    </message>
    <message>
        <source>All Loci</source>
        <translation>Alle loci</translation>
    </message>
    <message>
        <source>All Measurements</source>
        <translation>Alle metingen</translation>
    </message>
    <message>
        <source>All Calculations</source>
        <translation>Alle berekeningen</translation>
    </message>
    <message>
        <source>Enter new group name:</source>
        <translation>Voer nieuwe groepsnaam in:</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected group(s)?</source>
        <translation>Weet je zeker dat je de geselecteerde groep(en) wil verwijderen?</translation>
    </message>
</context>
<context>
    <name>KSegView</name>
    <message>
        <source>Untitled</source>
        <translation>Naamloos</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Klaar</translation>
    </message>
    <message>
        <source>Move label of %1 %2</source>
        <comment>E.g. &quot;Move label of Point P1&quot;</comment>
        <translation>Verplaats de label van %1 %2</translation>
    </message>
    <message>
        <source>Select %1 %2</source>
        <translation>Selecteer %1 %2</translation>
    </message>
    <message>
        <source>Deselect %1 %2</source>
        <translation>Deselecteer %1 %2</translation>
    </message>
    <message>
        <source>Also select %1 %2</source>
        <translation>Selecteer ook %1 %2</translation>
    </message>
    <message>
        <source>Move Selected Objects</source>
        <translation>Verplaats geselecteerde objecten</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to be free</source>
        <translation>Reconstrueer %1 %2 zodat ze vrij staan</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to %3 %4</source>
        <comment>E.g., &quot;Reconstrain Point P1 to Line l1&quot;</comment>
        <translation>Reconstrueer %1 %2 naar %3 %4</translation>
    </message>
    <message>
        <source>Reconstrain %1 %2 to the intersection of %3 %4 and %5 %6</source>
        <translation>Reconstrueer %1 %2 op het snijpunt van %3 %4 en %5 %6</translation>
    </message>
    <message>
        <source>Pan</source>
        <translation>Schuiven</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Zoomen</translation>
    </message>
</context>
<context>
    <name>KSegWindow</name>
    <message>
        <source>kseg: Untitled</source>
        <translation>kseg: Naamloos</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Bestand</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Be&amp;werken</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nieuw</translation>
    </message>
    <message>
        <source>Meas&amp;ure</source>
        <translation>&amp;Meting</translation>
    </message>
    <message>
        <source>&amp;Transform</source>
        <translation>&amp;Transformeer</translation>
    </message>
    <message>
        <source>Pla&amp;y</source>
        <translation>&amp;Speel af</translation>
    </message>
    <message>
        <source>Const&amp;ruction</source>
        <translation>&amp;Macro</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;New Sketch</source>
        <translation>&amp;Nieuwe tekening</translation>
    </message>
    <message>
        <source>Ne&amp;w Construction</source>
        <translation>Nieu&amp;we macro</translation>
    </message>
    <message>
        <source>New &amp;View</source>
        <translation>Nieuw &amp;beeld</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Openen...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Opslaan</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Opslaan &amp;Als...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Afdrukken...</translation>
    </message>
    <message>
        <source>Choose &amp;Language...</source>
        <translation>Kies &amp;Taal...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Ongedaan maken</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Opnieuw</translation>
    </message>
    <message>
        <source>&amp;Delete Objects</source>
        <translation>&amp;Verwijder objecten</translation>
    </message>
    <message>
        <source>Toggle &amp;Label</source>
        <translation>&amp;Labels aan of uit</translation>
    </message>
    <message>
        <source>Hide Label</source>
        <translation>Verberg label</translation>
    </message>
    <message>
        <source>Show Label</source>
        <translation>Laat label zien</translation>
    </message>
    <message>
        <source>Change La&amp;bel...</source>
        <translation>Verander la&amp;bel...</translation>
    </message>
    <message>
        <source>&amp;Hide Objects</source>
        <translation>&amp;Verberg objecten</translation>
    </message>
    <message>
        <source>&amp;Unhide All</source>
        <translation>&amp;Maak alle objecten zichtbaar</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>&amp;Kleur</translation>
    </message>
    <message>
        <source>Line &amp;Style</source>
        <translation>Lijn&amp;type</translation>
    </message>
    <message>
        <source>&amp;Point Style</source>
        <translation>&amp;Puntdikte</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Lettertype</translation>
    </message>
    <message>
        <source>Change &amp;Number of Samples...</source>
        <translation>Verander &amp;aantal voorbeelden...</translation>
    </message>
    <message>
        <source>&amp;Other...</source>
        <translation>&amp;Overigen...</translation>
    </message>
    <message>
        <source>&amp;Font...</source>
        <translation>&amp;Lettertype...</translation>
    </message>
    <message>
        <source>&amp;Intersection Point</source>
        <translation>&amp;Snijpunt</translation>
    </message>
    <message>
        <source>&amp;Segment</source>
        <translation>&amp;Lijnstuk</translation>
    </message>
    <message>
        <source>&amp;Midpoint</source>
        <translation>&amp;Middenpunt</translation>
    </message>
    <message>
        <source>&amp;Ray</source>
        <translation>&amp;Halve lijn</translation>
    </message>
    <message>
        <source>&amp;Line</source>
        <translation>&amp;Lijn</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Line</source>
        <translation>&amp;Loodlijn</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Point</source>
        <translation>&amp;Cirkel door middenpunt en punt</translation>
    </message>
    <message>
        <source>&amp;Arc By Three Points</source>
        <translation>B&amp;oog door drie punten</translation>
    </message>
    <message>
        <source>Angle &amp;Bisector</source>
        <translation>&amp;Bisectrice</translation>
    </message>
    <message>
        <source>L&amp;ocus</source>
        <translation>L&amp;ocus</translation>
    </message>
    <message>
        <source>Poly&amp;gon</source>
        <translation>Poly&amp;goon</translation>
    </message>
    <message>
        <source>Arc S&amp;ector</source>
        <translation>Booggebi&amp;ed</translation>
    </message>
    <message>
        <source>Arc Se&amp;gment</source>
        <translation>Boog&amp;stuk</translation>
    </message>
    <message>
        <source>Circle I&amp;nterior</source>
        <translation>Cirkelbi&amp;nnenkant</translation>
    </message>
    <message>
        <source>&amp;Distance</source>
        <translation>&amp;Afstand</translation>
    </message>
    <message>
        <source>&amp;Length</source>
        <translation>&amp;Lengte</translation>
    </message>
    <message>
        <source>&amp;Radius</source>
        <translation>&amp;Straal</translation>
    </message>
    <message>
        <source>&amp;Angle</source>
        <translation>&amp;Hoek</translation>
    </message>
    <message>
        <source>Ra&amp;tio</source>
        <translation>Ve&amp;rhouding</translation>
    </message>
    <message>
        <source>&amp;Slope</source>
        <translation>&amp;Hellingshoek</translation>
    </message>
    <message>
        <source>Ar&amp;ea</source>
        <translation>&amp;Oppervlakte</translation>
    </message>
    <message>
        <source>&amp;Calculate...</source>
        <translation>&amp;Bereken...</translation>
    </message>
    <message>
        <source>Choose &amp;Vector</source>
        <translation>Maak &amp;Vector</translation>
    </message>
    <message>
        <source>Choose &amp;Mirror</source>
        <translation>Maak &amp;Spiegel</translation>
    </message>
    <message>
        <source>Choose &amp;Center</source>
        <translation>Maak &amp;Middenpunt</translation>
    </message>
    <message>
        <source>Choose &amp;Angle</source>
        <translation>Kies &amp;Hoek</translation>
    </message>
    <message>
        <source>Choose Rati&amp;o</source>
        <translation>Kies &amp;Verhouding</translation>
    </message>
    <message>
        <source>C&amp;lear Chosen</source>
        <translation>&amp;Wis aangemaakte hulpstukken</translation>
    </message>
    <message>
        <source>&amp;Translate</source>
        <translation>&amp;Transleer</translation>
    </message>
    <message>
        <source>R&amp;eflect</source>
        <translation>&amp;Spiegel</translation>
    </message>
    <message>
        <source>&amp;Scale</source>
        <translation>S&amp;chalen</translation>
    </message>
    <message>
        <source>&amp;Rotate</source>
        <translation>&amp;Roteren</translation>
    </message>
    <message>
        <source>Make &amp;Normal</source>
        <translation>&amp;Demarkeer</translation>
    </message>
    <message>
        <source>Make &amp;Given</source>
        <translation>&amp;Markeer als gegeven</translation>
    </message>
    <message>
        <source>Make &amp;Final</source>
        <translation>Markeer als &amp;einde</translation>
    </message>
    <message>
        <source>Make &amp;Initial</source>
        <translation>Markeer als &amp;begin</translation>
    </message>
    <message>
        <source>&amp;Recurse</source>
        <translation>&amp;Herhaal</translation>
    </message>
    <message>
        <source>&amp;Quick Play</source>
        <translation>&amp;Speel af</translation>
    </message>
    <message>
        <source>&amp;About...</source>
        <translation>&amp;Over...</translation>
    </message>
    <message>
        <source>&amp;Circumference</source>
        <translation>&amp;Omtrek</translation>
    </message>
    <message>
        <source>Arc &amp;Length</source>
        <translation>Boog&amp;lengte</translation>
    </message>
    <message>
        <source>Toggle &amp;Labels</source>
        <translation>&amp;Labels aan of uit</translation>
    </message>
    <message>
        <source>Hide Labels</source>
        <translation>Labels verbergen</translation>
    </message>
    <message>
        <source>Show Labels</source>
        <translation>Laat label zien</translation>
    </message>
    <message>
        <source>&amp;Segments</source>
        <translation>&amp;Lijnstukken</translation>
    </message>
    <message>
        <source>&amp;Rays</source>
        <translation>&amp;Halve lijnen</translation>
    </message>
    <message>
        <source>&amp;Midpoints</source>
        <translation>&amp;Middenpunten</translation>
    </message>
    <message>
        <source>&amp;Intersection Points</source>
        <translation>&amp;Snijpunten</translation>
    </message>
    <message>
        <source>&amp;Circle By Center And Radius</source>
        <translation>&amp;Cirkel door middenpunt en punt</translation>
    </message>
    <message>
        <source>&amp;Lines</source>
        <translation>&amp;Lijnen</translation>
    </message>
    <message>
        <source>Parallel &amp;Lines</source>
        <translation>Parallelle &amp;lijnen</translation>
    </message>
    <message>
        <source>Parallel &amp;Line</source>
        <translation>Parallel &amp;Lijn</translation>
    </message>
    <message>
        <source>&amp;Perpendicular Lines</source>
        <translation>Loodli&amp;jnen</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Naamloos</translation>
    </message>
    <message>
        <source>&amp;Change Directory...</source>
        <translation>&amp;Wijzig map...</translation>
    </message>
    <message>
        <source>No Constructions</source>
        <translation>Geen macro&apos;s</translation>
    </message>
    <message>
        <source>Save?</source>
        <translation>Bewaren?</translation>
    </message>
    <message>
        <source>Would you like to save your changes?</source>
        <translation>Veranderingen bewaren?</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Bestand niet gevonden</translation>
    </message>
    <message>
        <source>Sorry, I am afraid that file %1 does not exist.</source>
        <translation>Sorry, ik ben bang dat bestand %1 niet bestaat.</translation>
    </message>
    <message>
        <source>Invalid file</source>
        <translation>Ongeldig bestand</translation>
    </message>
    <message>
        <source>The file %1 does not look like a valid KSEG file.</source>
        <translation>Het bestand %1 lijkt niet op een geldig KSEG bestand.</translation>
    </message>
    <message>
        <source>Language Change</source>
        <translation>Wijzig taal</translation>
    </message>
    <message>
        <source>You will need to restart KSEG for the language change to fully take effect.</source>
        <translation>Je moet KSEG opnieuw starten voordat deze wijzingen doorgevoerd zijn.</translation>
    </message>
    <message>
        <source>About KSEG</source>
        <translation>Over KSEG</translation>
    </message>
    <message>
        <source>&amp;Delete Object</source>
        <translation>&amp;Verwijder object</translation>
    </message>
    <message>
        <source>&amp;Hide Object</source>
        <translation>&amp;Verberg object</translation>
    </message>
    <message>
        <source>Pr&amp;eferences...</source>
        <translation>&amp;Voorkeuren...</translation>
    </message>
    <message>
        <source>KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</source>
        <translation>KSEG v%1
Copyright (C) %2 Ilya Baran
http://www.mit.edu/~ibaran
ibaran@mit.edu</translation>
    </message>
    <message>
        <source>Open In Current Window...</source>
        <translation>Open in huidige venster...</translation>
    </message>
    <message>
        <source>Copy As Construction</source>
        <translation>Kopieer als macro</translation>
    </message>
    <message>
        <source>Selection &amp;Groups...</source>
        <translation>Selecteer &amp;groepen...</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation>&amp;Zoomen</translation>
    </message>
    <message>
        <source>&amp;Pan</source>
        <translation>&amp;Schuiven</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Beeld</translation>
    </message>
    <message>
        <source>Zoom To &amp;Fit</source>
        <translation>&amp;Passend inzoomen</translation>
    </message>
    <message>
        <source>&amp;Original Zoom (100%)</source>
        <translation>&amp;Oorspronkelijk zoomniveau (100%)</translation>
    </message>
    <message>
        <source>E&amp;xport To Image...</source>
        <translation>Als plaatje e&amp;xporteren...</translation>
    </message>
    <message>
        <source>Endpoints</source>
        <translation>Eindpunten</translation>
    </message>
    <message>
        <source>Center Point</source>
        <translation>Middenpunt</translation>
    </message>
    <message>
        <source>Endpoint</source>
        <translation>Eindpunt</translation>
    </message>
    <message>
        <source>Zoom:</source>
        <translation>Zoomen:</translation>
    </message>
    <message>
        <source>Choose the File Format:</source>
        <translation>Kies het bestandsformaat:</translation>
    </message>
    <message>
        <source>High Quality Image</source>
        <translation>Hoge kwaliteit</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Exporting, Please wait...</source>
        <translation>Even geduld alstublieft, bezig met exporteren...</translation>
    </message>
</context>
<context>
    <name>MatrixDialog</name>
    <message>
        <source>Rows:</source>
        <translation>Rijen:</translation>
    </message>
    <message>
        <source>Columns:</source>
        <translation>Kolommen:</translation>
    </message>
    <message>
        <source>Zero-Fill</source>
        <translation>Leeg</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
</context>
</TS>
